@@ -339,3 +339,17 @@ class Backend(_Backend):
             )
             _value = self._get_key_when_ready(k_ref)
         return _value
+
+    def get_struct(self, schema: dict, **kwargs) -> dict:
+        """ """
+        _struct = {}
+
+        _path = kwargs.get("path", self.default_key_path)
+        kv_store = self._get_kv_store_when_ready(path=_path)
+        for key, v_type in schema.items():
+            _value = kv_store.get(key)
+            if _value is not None:
+                _value = self._cast(_value, v_type=v_type)
+            _struct[key] = _value
+
+        return _struct
